This implements the trivial change needed to move back from the hip{Something}_{x, y, z} macros to the natural CUDA syntax of Something.{x, y, z}. This is contained in lines 384-404 in hip_runtime.h. All of the other changes have to do with changing unit tests to use this syntax. The macros are retained for backwards compatibility.

[ROCm/hip commit: cffd0e14eb]
This commit is contained in:
Alex Voicu
2017-11-19 01:54:12 +00:00
parent 0fd5239b14
commit 962bf7bfda
60 changed files with 270 additions and 248 deletions
@@ -26,7 +26,7 @@ THE SOFTWARE.
static size_t size[NUM_SIZE];
__global__ void Add(hipLaunchParm lp, int *Ad){
int tx = hipThreadIdx_x;
int tx = threadIdx.x;
Ad[tx] = Ad[tx] + tx;
}